@@ -53,18 +53,17 @@ if [ "$should_push" != "y" ]; then
     exit 1
 fi
 
-git commit -m "Update for $tag" -a
+if [ -n "$(git status --porcelain)" ]; then
+    git commit -m "Update for $tag" -a
+fi
 
 git push
 
-message="$version
-
-$notes"
-
-hub release create -m "$message" "$tag"
+gh release create --target "$(git branch --show-current)" -t "$version" -n "$notes" "$tag"
 
 git push --tags
 
-rm -fr dist
-python setup.py build_html sdist
+rm -fr build dist
+python -m sphinx -M html ./docs ./build/sphinx -W
+python setup.py sdist
 twine upload dist/*
